@@ -1,14 +1,11 @@
 package Text::FIGlet::Control;
+require 5;
 use strict;
 use vars '$VERSION';
 use Carp 'croak';
-$VERSION = 2.15;
-
-#'import' core support functions from parent with circular dependency
-foreach( qw/_canonical _no/){
-  no strict 'refs';
-  *$_ = *{'Text::FIGlet::'.$_};
-}
+use File::Basename 'fileparse';
+use File::Spec;
+$VERSION = 2.01;
 
 sub new{
   my $proto = shift;
@@ -19,23 +16,19 @@ sub new{
   my(@t_pre, @t_post);
   while( @_ ){
     my $s = shift;
-    if( $s eq '-C' ){
-	push(@{$self->{-C}}, shift); }
-    else{
-	$self->{$s} = shift; }
+    $self->{-d} = shift if $s eq '-d';
+    push(@{$self->{-C}}, shift) if $s eq '-C';
   }
   $self->{-d} ||= $ENV{FIGLIB}  || '/usr/games/lib/figlet/';
-  $self->{"_\\"} = 1 if $^O =~ /MSWin32|DOS/i;
 
 
 #  my $no = qr/0x[\da-fA-F]+|\d+/;
 
   foreach my $flc ( @{$self->{-C}} ){
-    $self->{'_file'} = _canonical($self->{-d},
-						$flc,
-						qr/\.flc/,
-						$self->{"_\\"});
-    open(FLC, $self->{'_file'}) || croak("$!: $flc [$self->{_file}]");
+    my($file, $path) = fileparse($flc, '\.flc');
+    $path = $self->{-d} if $path eq './' && index($flc, './') < 0;
+    
+    open(FLC, File::Spec->catfile($path, $file.'.flc')) || croak("$!: $flc");
     while(<FLC>){
       next if /^flc2a|\s*#|^\s*$/;
 
@@ -45,14 +38,14 @@ sub new{
       if( /^\s*$Text::FIGlet::RE{no}\s+$Text::FIGlet::RE{no}\s*/ ){
 	#Only needed for decimals?!
 
-	push @t_pre,  sprintf('\\x{%x}', _no($1, $2, $3));
-	push @t_post, sprintf('\\x{%x}', _no($4, $5, $6));
+	push @t_pre,  sprintf('\\x{%x}', Text::FIGlet::_no($1, $2, $3));
+	push @t_post, sprintf('\\x{%x}', Text::FIGlet::_no($4, $5, $6));
       }
       elsif( /^\s*t\s+\\?$Text::FIGlet::RE{no}(?:-\\$Text::FIGlet::RE{no})?\s+\\?$Text::FIGlet::RE{no}(?:-\\$Text::FIGlet::RE{no})?\s*/ ){
-	push @t_pre,  sprintf( '\\x{%x}', _no( $1, $2, $3));
-	push @t_post, sprintf( '\\x{%x}', _no( $7, $8, $9));
-	$t_pre[-1] .= sprintf('-\\x{%x}', _no( $4, $5, $6)) if$5;
-	$t_post[-1].= sprintf('-\\x{%x}', _no($10,$11,$12))if$11;
+	push @t_pre,  sprintf( '\\x{%x}', Text::FIGlet::_no( $1, $2, $3));
+	push @t_post, sprintf( '\\x{%x}', Text::FIGlet::_no( $7, $8, $9));
+	$t_pre[-1] .= sprintf('-\\x{%x}', Text::FIGlet::_no( $4, $5, $6)) if$5;
+	$t_post[-1].= sprintf('-\\x{%x}', Text::FIGlet::_no($10,$11,$12))if$11;
       }
       elsif( /^\s*t\s+([^\s](?:-[^\s])?)\s+([^\s](?:-[^\s])?)\s*/ ){
 	push @t_pre,  $1;
@@ -126,7 +119,7 @@ Note that this is required for perl 5.6 if you are doing negative mapping.
 
 =head1 OPTIONS
 
-=head2 C<new>
+C<new>
 
 =over
 
@@ -160,7 +153,7 @@ returned will be an aggregate of the specified controls.
 
 =back
 
-=head2 C<tr>
+C<tr>
 
 =over
 
@@ -182,24 +175,12 @@ will make use of these environment variables if present
 The default location of fonts.
 If undefined the default is F</usr/games/lib/figlet>
 
-=back
-
 =head1 FILES
 
 FIGlet control files are available at
 
   ftp://ftp.figlet.org/pub/figlet/
 
-=head1 CAVEATS
-
-There is a mystery bug in perls 5.6.1 and 5.6.2 which can cause seemingly
-simple transliterations to fail. The standard figlet(1) F<upper.flc> is an
-example of such a transliteration. For this reason, the enclosed F<upper.flc>
-uses a C<freeze> after the ASCII swapping. I've no idea why, but it seems to
-work. If you experience similar problems with other control files, try some
-shotgun debugging with freezes yourself. Modern perls, 5.6.0 and even 5.005_05
-do not have this problem.
-
 =head1 SEE ALSO
 
 L<Text::FIGlet>, L<figlet(6)>, L<tr(1)>
